@@ -81,7 +81,7 @@ class PriorityQueue:
                 break
             top_n_list.append(copy.pop())
             count += 1
-        return top_n_list
+        return top_n_list  # [priority / priority, key]
 
     def pop(self):
         """ O(logN) """
@@ -151,7 +151,7 @@ class PriorityMap(PriorityQueue):
         """ O(1) """
         if len(self) <= 0:
             raise IndexError("Peek at an empty queue")
-        return self.heap[0]
+        return self.heap[0]  # priority, key
 
     def top_n(self, n: int = None) -> list():
         if n is not None and n < 0:
@@ -165,7 +165,7 @@ class PriorityMap(PriorityQueue):
                 break
             top_n_list.append(copy.pop())
             count += 1
-        return top_n_list
+        return top_n_list  # [priority / priority, key]
 
     def push(self, *priority_n_key):
         """ O(logN) """
@@ -198,12 +198,17 @@ class PriorityMap(PriorityQueue):
         if key not in self:
             raise KeyError(f"{key} not found")
         index = self.map[key]
-        tail_item = self.heap[-1]
-        self.map[tail_item[1]] = index
-        self.heap[index] = tail_item
-        del self.map[key]
-        self.heap.pop()
-        self._sift_up(index)
+        if index == len(self.heap) - 1:  # the key to delete is at the end of heap
+            del self.map[key]
+            return self.heap.pop()  # priority / priority, key
+        else:
+            tail_item = self.heap[-1]
+            self.map[tail_item[1]] = index
+            self.heap[index] = tail_item
+            del self.map[key]
+            item = self.heap.pop()
+            self._sift_up(index)
+            return item  # priority / priority, key
 
     def update(self, *priority_n_key):
         """ O(logN) """
