@@ -41,12 +41,13 @@ class Square:
 
 
 class Maze:
-    def __init__(self, row: int = 10, col: int = 10, obstacle_percentage=0.1, text_only=False):
+    def __init__(self, row: int = 10, col: int = 10, obstacle_percentage=0.1, text_only=False, show_searched=False):
         self.row_len = row
         self.col_len = col
         self.map = [[None for _ in range(col)] for _ in range(row)]
         self.obstacle_percentage = obstacle_percentage
         self.text_only = text_only
+        self.show_searched = show_searched
 
     def build_map(self):
         obstacles = self.row_len * self.col_len * self.obstacle_percentage
@@ -144,8 +145,9 @@ class Maze:
             return path, searched
 
         path, searched = a_star_shortest_path(source, destination)
-        for node in searched:
-            self.map[node[0]][node[1]] = Square.State.Searched
+        if self.show_searched:
+            for node in searched:
+                self.map[node[0]][node[1]] = Square.State.Searched
         parent = path[destination]
         self.map[destination[0]][destination[1]] = Square.State.Path
         while parent:
@@ -165,7 +167,8 @@ parser = argparse.ArgumentParser(description="Maze")
 parser.add_argument("-r", "--row", dest="row", type=int, default=10, help="Number of rows")
 parser.add_argument("-c", "--column", dest="col", type=int, default=10, help="Number of columns")
 parser.add_argument("-t", "--text-only", dest="text_only", action="store_true", default=False, help="Print Map in Text")
+parser.add_argument("-s", "--show-searched-area", dest="show_searched", action="store_true", default=False)
 parser.add_argument("-o", "--obstacles-percentage", dest="op", type=float, default=0.1)
 args = parser.parse_args()
 if __name__ == "__main__":
-    Maze(row=args.row, col=args.col, obstacle_percentage=args.op, text_only=args.text_only).run()
+    Maze(row=args.row, col=args.col, obstacle_percentage=args.op, text_only=args.text_only, show_searched=args.show_searched).run()
